@@ -2,24 +2,28 @@ from typing import Any, Optional
 
 from sanic.exceptions import SanicException
 
-from .enum import Field, RespCodeEnum
+from .enum import EnumBase, Field, RespCodeEnum
 
 
 class ServerException(SanicException):
     def __init__(
         self,
-        message: str = None,
-        server_code: Optional[Any] = None,
+        message: Optional[str] = None,
+        server_code: Optional[EnumBase] = None,
         status_code: Optional[int] = None,
         quiet: Optional[bool] = None,
         context: Any = None,
         extra=None,
     ) -> None:
         super(ServerException, self).__init__(
-            message=message, status_code=status_code, quiet=quiet, context=context, extra=extra
+            message=message,
+            status_code=status_code,
+            quiet=quiet,
+            context=context,
+            extra=extra,
         )
         self.server_code = server_code or RespCodeEnum.FAILED
-        self.message = message or server_code.desc
+        self.message = message or self.server_code.desc
         self.status_code = status_code or 200
 
 
@@ -35,4 +39,6 @@ class ValidationError(ServerException):
     """
 
     def __init__(self, errors: list, *args, **kwargs):
-        super(ValidationError, self).__init__(server_code=RespCodeEnum.PARAM_FAILED, context=errors)
+        super(ValidationError, self).__init__(
+            server_code=RespCodeEnum.PARAM_FAILED, context=errors
+        )
